.. image:: http://libearth.earthreader.org/en/0.2.0/_static/libearth.svg?
   :width: 132
   :height: 139


libearth
========

Libearth is the shared common library for various `Earth Reader`_ apps.

.. _Earth Reader: http://earthreader.org/


Installation
------------

You can install it using ``pip``:

.. code-block:: console

   $ pip install libearth


Links
-----

Package Index (PyPI)
   https://pypi.python.org/pypi/libearth

   .. image:: http://img.shields.io/pypi/v/libearth.svg
      :target: https://pypi.python.org/pypi/libearth

Docs (ReadTheDocs)
   http://libearth.earthreader.org/

Git repository (GitHub)
   https://github.com/earthreader/libearth

Issue tracker (GitHub)
   https://github.com/earthreader/libearth/issues

Mailing list
   earthreader@librelist.com

List archive
   http://librelist.com/browser/earthreader/

Continuous integration (Travis)
   https://travis-ci.org/earthreader/libearth

   .. image:: https://travis-ci.org/earthreader/libearth.svg
      :alt: Build Status
      :target: https://travis-ci.org/earthreader/libearth

Test coverage (Coveralls)
   https://coveralls.io/r/earthreader/libearth

   .. image:: https://img.shields.io/coveralls/earthreader/libearth.svg
      :alt: Coverage Status
      :target: https://coveralls.io/r/earthreader/libearth?branch=master
